Changelog
=========

0.2.4 (2024-08-14)
------------------

- Corrected set_parameter. Added hostname information.
  [sgeulette]

0.2.3 (2024-08-14)
------------------

- Send an info message (no mail) when the product is updated.
  [sgeulette]

0.2.2 (2024-08-13)
------------------

- Added `--is-auto-started` parameter in main, passed when app is auto started.
  [sgeulette]

0.2.1 (2024-08-13)
------------------

- Changed backup directory.
  [sgeulette]
- Improved exception logging.
  [sgeulette]

0.2.0 (2024-08-13)
------------------

- Added profiles_backup script.
  [sgeulette]
- Stored client identification, plone password and webservice url in configuration file.
  [sgeulette]
- Added profiles_restore script.
  [sgeulette]

0.1.1 (2024-07-19)
------------------

- Handled Windows startup add or remove following parameters.
  [sgeulette]

0.1.0 (2024-07-18)
------------------

- Initial release.
  [sgeulette]
